@@ -39,11 +39,12 @@ function xapp () {
 	ioff="--iconoffset=2"
     else
 	icon=--icon=$(canonicalize "$app")
-	ioff="--iconoffset=$2"
+	ioff="--iconoffset=$1"
     fi
     shift
+    args="$1"
     test -d "${folder}" || mkdir -p "${folder}"
-    mkshortcut "${icon}" "${ioff}" --arguments=-p\ /usr/X11R6/bin\ ${app}\ -display\ 127.0.0.1:0.0\ "$@" \
+    mkshortcut "${icon}" "${ioff}" --arguments=-p\ /usr/X11R6/bin\ ${app}\ -display\ 127.0.0.1:0.0\ "${args}" \
 	--name="${folder}/${app}" \
         --desc="${description}" \
 	--workingdir=/bin /usr/X11R6/bin/run.exe
@@ -57,8 +58,9 @@ function tapp () {
     shift
     folder="${TOPFOLDER}/$1"
     shift
+    args="$1"
     test -d "${folder}" || mkdir -p "${folder}"
-    mkshortcut --arguments=-p\ /usr/X11R6/bin\ xterm\ -display\ 127.0.0.1:0.0\ -e\ bash\ -c\ \"/usr/X11R6/bin/${app}\ -display\ 127.0.0.1:0.0\ "$@"\ "| /bin/less"\" \
+    mkshortcut --arguments=-p\ /usr/X11R6/bin\ xterm\ -display\ 127.0.0.1:0.0\ -e\ bash\ -c\ \"/usr/X11R6/bin/${app}\ -display\ 127.0.0.1:0.0\ "${args}"\ "| /bin/less"\" \
 	--name="${folder}/${app}" \
         --desc="${description}" \
 	--icon=/cygwin.ico \
@@ -78,10 +80,10 @@ function create_icons () {
 	test $? -eq 0 || continue
 	case $4 in
 	xapp)
-	    xapp $1 "$2" "$3" $5 $6
+	    xapp "$1" "$2" "$3" "$5" "$6"
 	    ;;
 	tapp)
-	    tapp $1 "$2" "$3" $6
+	    tapp "$1" "$2" "$3" "$6"
 	    ;;
 	*)
 	    echo `hosed!`
@@ -97,8 +99,8 @@ function destroy_icons () {
 	test -z "$a" && continue
 	# This next line breaks up the elements and set $1..$6 appropriately
 	IFS=":";set $a;unset IFS
-	icon="${TOPFOLDER}/${3}/${2}.lnk"
-	test -f "${icon}" && \rm -f "${icon}"
+	icon="${TOPFOLDER}/${3}/${1}.lnk"
+	test -f "${icon}" && rm -f "${icon}"
     done
     # Removal of TOPFOLDER will fail because find has a lock on it
     # Thus, we add -mindepth 1 to prevent an attempt to remove TOPFOLDER
